0.9.9 API documentation: matrix_transform.hpp Source File

| 0.9.9 API documentation

- Main Page
- Modules
- Files

- File List

ext/matrix_transform.hpp
Go to the documentation of this file.
1
20 #pragma once
21
22 // Dependencies
23 #include "../gtc/constants.hpp"
24 #include "../geometric.hpp"
25 #include "../trigonometric.hpp"
26 #include "../matrix.hpp"
27
28 #if GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
29 # pragma message("GLM: GLM_EXT_matrix_transform extension included")
30 #endif
31
32 namespace glm
33 {
36
38 template<typename genType>
39 GLM_FUNC_DECL GLM_CONSTEXPR genType identity();
40
63 template<typename T, qualifier Q>
64 GLM_FUNC_DECL mat<4, 4, T, Q> translate(
65 mat<4, 4, T, Q> const& m, vec<3, T, Q> const& v);
66
79 template<typename T, qualifier Q>
80 GLM_FUNC_DECL mat<4, 4, T, Q> rotate(
81 mat<4, 4, T, Q> const& m, T angle, vec<3, T, Q> const& axis);
82
94 template<typename T, qualifier Q>
95 GLM_FUNC_DECL mat<4, 4, T, Q> scale(
96 mat<4, 4, T, Q> const& m, vec<3, T, Q> const& v);
97
108 template<typename T, qualifier Q>
109 GLM_FUNC_DECL mat<4, 4, T, Q> lookAtRH(
110 vec<3, T, Q> const& eye, vec<3, T, Q> const& center, vec<3, T, Q> const& up);
111
122 template<typename T, qualifier Q>
123 GLM_FUNC_DECL mat<4, 4, T, Q> lookAtLH(
124 vec<3, T, Q> const& eye, vec<3, T, Q> const& center, vec<3, T, Q> const& up);
125
137 template<typename T, qualifier Q>
138 GLM_FUNC_DECL mat<4, 4, T, Q> lookAt(
139 vec<3, T, Q> const& eye, vec<3, T, Q> const& center, vec<3, T, Q> const& up);
140
142 }//namespace glm
143
144 #include "matrix_transform.inl"
glm::lookAtLH
GLM_FUNC_DECL mat< 4, 4, T, Q > lookAtLH(vec< 3, T, Q > const &eye, vec< 3, T, Q > const &center, vec< 3, T, Q > const &up)
Build a left handed look at view matrix.
glm::lookAtRH
GLM_FUNC_DECL mat< 4, 4, T, Q > lookAtRH(vec< 3, T, Q > const &eye, vec< 3, T, Q > const &center, vec< 3, T, Q > const &up)
Build a right handed look at view matrix.
glm::angle
GLM_FUNC_DECL T angle(qua< T, Q > const &x)
Returns the quaternion rotation angle.
glm::translate
GLM_FUNC_DECL mat< 4, 4, T, Q > translate(mat< 4, 4, T, Q > const &m, vec< 3, T, Q > const &v)
Builds a translation 4 * 4 matrix created from a vector of 3 components.
glm::rotate
GLM_FUNC_DECL mat< 4, 4, T, Q > rotate(mat< 4, 4, T, Q > const &m, T angle, vec< 3, T, Q > const &axis)
Builds a rotation 4 * 4 matrix created from an axis vector and an angle.
glm::identity
GLM_FUNC_DECL GLM_CONSTEXPR genType identity()
Builds an identity matrix.
glm::scale
GLM_FUNC_DECL mat< 4, 4, T, Q > scale(mat< 4, 4, T, Q > const &m, vec< 3, T, Q > const &v)
Builds a scale 4 * 4 matrix created from 3 scalars.
glm::axis
GLM_FUNC_DECL vec< 3, T, Q > axis(qua< T, Q > const &x)
Returns the q rotation axis.
glm::lookAt
GLM_FUNC_DECL mat< 4, 4, T, Q > lookAt(vec< 3, T, Q > const &eye, vec< 3, T, Q > const &center, vec< 3, T, Q > const &up)
Build a look at view matrix based on the default handedness.
glm
Definition: common.hpp:20